# Google Air Quality API

[![codecov](https://codecov.io/gh/Thomas55555/python-google-air-quality-api/graph/badge.svg?token=mCoquN2d11)](https://codecov.io/gh/Thomas55555/python-google-air-quality-api)
[![Python Versions](https://img.shields.io/pypi/pyversions/google_air_quality_api)](https://pypi.org/project/google_air_quality_api/)
[![License](https://img.shields.io/github/license/Thomas55555/python-google-air-quality-api.svg)](LICENSE.md)

A python client library for the Google Air Quality API.

The Google Google Air API allows to get air qulaity information.
See [Google Air Quality APIs](https://developers.google.com/maps/documentation/air-quality/overview)
for more details on how to integrate Google Air Quality with your application.

## Background

This is a thin wrapper around the API used for a very lightweight abstraction. The
primary use case is for Home Assistant though can be used for other usages.
